//==============================================================================
//==============================================================================
#define F_CPU 8000000UL
#include <avr/io.h>
#include <avr/interrupt.h>   
#include <avr/sleep.h>
#include <util/delay.h>

#define LEDBLUE PC0   // синий светодиод

extern unsigned char chas, mins, sec;

// режим работы, 1 - питание от сети, 0 - работа от аккумулятора
extern unsigned char regim;  // текущее значение
//==============================================================================
// таймер работает в асинхронном режиме с кварцем 32768 Гц
void initT2(void)
{ ASSR |= (1<<AS2);           // Включаем асинхронный режим T2
  TCNT2 = 0;
  TCCR2A = 0x00;
  TCCR2B = (5<<CS20);
  OCR2A  = 0x00;
  OCR2B  = 0x00;
  TIMSK2 |= (1 << TOIE2);
}
//==============================================================================
void minit(void)
{ 
  PORTB = 0x00; DDRB  = 0x00;
  PORTC = 0x00; DDRC  = 0x00;
  PORTD = 0x00; DDRD  = 0x00;
  CLKPR = 0x80; CLKPR = 0x00; 
  UCSR0B = 0x00;

  ACSR   = 0x80;
  ADCSRB = 0x00;
  DIDR1  = 0x00;
  ADCSRA = 0x00;
  SPCR   = 0x00;
  TWCR   = 0x00;

  EICRA = 0x00;
  EIMSK = 0x00;
  PCICR = 0x00;
  TIMSK1 = 0x00; 
  TIMSK2 = 0x00;

  initT2();

  set_sleep_mode(SLEEP_MODE_PWR_SAVE);  // установка параметров малопотребляющего режима
  sleep_enable();

  DDRC |= (1<<LEDBLUE);
  
  sei();
}
//==============================================================================
// "спящий" режим
void mslipping(void)
{ 
  PORTB = 0;
  PORTD = 0;
  SPCR &= ~(1<<SPE);  // выключение SPI 
  _delay_ms(1);
  while(ASSR & (1<<TCN2UB)) {;}
  _delay_us(100);
  asm("sleep");
  _delay_us(100);
}
//==============================================================================
ISR(TIMER2_OVF_vect)
{  
  sec++;
  {
    if (sec > 59)
    { sec = 0;
      mins++; 
      if (mins > 59)
      { mins = 0;
        chas++;
        if (chas > 23) chas = 0;
      }
    }
  }
  PORTC |= (1<<LEDBLUE);
  _delay_us(100); // более тусклые в экономисном режиме
  if (regim == 1) _delay_ms(2);  // яркие вспышки
  PORTC &= ~(1<<LEDBLUE);
}
//==============================================================================
